@@ -16,7 +16,8 @@ mod internednames;
 use internednames::{InternedName, InternedNames};
 
 mod dirhandle;
-pub use dirhandle::{used_handles, Dir};
+use dirhandle::Dir;
+pub use dirhandle::used_handles;
 pub use openat_ct as openat;
 
 /// An user defined processing function can return any kind of error, this needs to be boxed
